@@ -9,12 +9,6 @@ from octis.evaluation_metrics.classification_metrics import F1Score
 
 from octis.evaluation_metrics.coherence_metrics import *
 from octis.dataset.dataset import Dataset
-from octis.models.LDA import LDA
-from octis.models.ETM import ETM
-from octis.models.CTM import CTM
-from octis.models.NMF import NMF
-from octis.models.NMF_scikit import NMF_scikit
-from octis.models.ProdLDA import ProdLDA
 
 import os
 from octis.preprocessing.preprocessing import Preprocessing
